@@ -242,9 +242,10 @@ var _ = Describe("Data Processor", func() {
 			transferResponse: ProcessingPhaseConvert,
 			url:              url,
 		}
-		dp := NewDataProcessor(mdp, "dest", "dataDir", tmpDir, "1G", 0.055, false)
+		dp := NewDataProcessor(mdp, "", "dataDir", tmpDir, "1G", 0.055, false)
 		dp.availableSpace = int64(1500)
-		usableSpace := int64((1 - 0.055) * float64(dp.availableSpace))
+		usableSpace := dp.getUsableSpace()
+
 		qemuOperations := NewFakeQEMUOperations(nil, nil, fakeInfoRet, nil, nil, resource.NewScaledQuantity(usableSpace, 0))
 		replaceQEMUOperations(qemuOperations, func() {
 			err = dp.ProcessData()
@@ -306,12 +307,14 @@ var _ = Describe("Convert", func() {
 
 var _ = Describe("Resize", func() {
 	It("Should not resize and return complete, when requestedSize is blank", func() {
+		tempDir, err := ioutil.TempDir(os.TempDir(), "dest")
+		Expect(err).ToNot(HaveOccurred())
 		url, err := url.Parse("http://fakeurl-notreal.fake")
 		Expect(err).ToNot(HaveOccurred())
 		mdp := &MockDataProvider{
 			url: url,
 		}
-		dp := NewDataProcessor(mdp, "dest", "dataDir", "scratchDataDir", "", 0.055, false)
+		dp := NewDataProcessor(mdp, tempDir, "dataDir", "scratchDataDir", "", 0.055, false)
 		qemuOperations := NewFakeQEMUOperations(nil, nil, fakeInfoOpRetVal{&fakeZeroImageInfo, nil}, nil, nil, nil)
 		replaceQEMUOperations(qemuOperations, func() {
 			nextPhase, err := dp.resize()
@@ -321,8 +324,11 @@ var _ = Describe("Resize", func() {
 	})
 
 	It("Should not resize and return complete, when requestedSize is valid, but datadir doesn't exist (block device)", func() {
+		tempDir, err := ioutil.TempDir(os.TempDir(), "dest")
+		Expect(err).ToNot(HaveOccurred())
+
 		replaceAvailableSpaceBlockFunc(func(dataDir string) (int64, error) {
-			Expect("dest").To(Equal(dataDir))
+			Expect(tempDir).To(Equal(dataDir))
 			return int64(100000), nil
 		}, func() {
 			url, err := url.Parse("http://fakeurl-notreal.fake")
@@ -330,7 +336,7 @@ var _ = Describe("Resize", func() {
 			mdp := &MockDataProvider{
 				url: url,
 			}
-			dp := NewDataProcessor(mdp, "dest", "dataDir", "scratchDataDir", "1G", 0.055, false)
+			dp := NewDataProcessor(mdp, tempDir, "dataDir", "scratchDataDir", "1G", 0.055, false)
 			qemuOperations := NewFakeQEMUOperations(nil, nil, fakeInfoOpRetVal{&fakeZeroImageInfo, nil}, nil, nil, nil)
 			replaceQEMUOperations(qemuOperations, func() {
 				nextPhase, err := dp.resize()
@@ -341,14 +347,14 @@ var _ = Describe("Resize", func() {
 	})
 
 	It("Should resize and return complete, when requestedSize is valid, and datadir exists", func() {
-		tmpDir, err := ioutil.TempDir("", "data")
+		tmpDir, err := ioutil.TempDir(os.TempDir(), "data")
 		Expect(err).ToNot(HaveOccurred())
 		url, err := url.Parse("http://fakeurl-notreal.fake")
 		Expect(err).ToNot(HaveOccurred())
 		mdp := &MockDataProvider{
 			url: url,
 		}
-		dp := NewDataProcessor(mdp, "dest", tmpDir, "scratchDataDir", "1G", 0.055, false)
+		dp := NewDataProcessor(mdp, tmpDir, tmpDir, "scratchDataDir", "1G", 0.055, false)
 		qemuOperations := NewFakeQEMUOperations(nil, nil, fakeInfoOpRetVal{&fakeZeroImageInfo, nil}, nil, nil, nil)
 		replaceQEMUOperations(qemuOperations, func() {
 			nextPhase, err := dp.resize()
@@ -358,7 +364,7 @@ var _ = Describe("Resize", func() {
 	})
 
 	It("Should not resize and return error, when ResizeImage fails", func() {
-		tmpDir, err := ioutil.TempDir("", "data")
+		tmpDir, err := ioutil.TempDir(os.TempDir(), "data")
 		Expect(err).ToNot(HaveOccurred())
 		url, err := url.Parse("http://fakeurl-notreal.fake")
 		Expect(err).ToNot(HaveOccurred())
@@ -399,22 +405,21 @@ var _ = Describe("Resize", func() {
 
 var _ = Describe("ResizeImage", func() {
 	//fakeInfoRet has info.VirtualSize=1024
-	table.DescribeTable("calling ResizeImage", func(qemuOperations image.QEMUOperations, imageSize string, totalSpace int64, wantErr bool, wantResized bool) {
+	table.DescribeTable("calling ResizeImage", func(qemuOperations image.QEMUOperations, imageSize string, totalSpace int64, wantErr bool) {
 		replaceQEMUOperations(qemuOperations, func() {
-			resized, err := ResizeImage("dest", imageSize, totalSpace)
+			err := ResizeImage("dest", imageSize, totalSpace, false)
 			if !wantErr {
 				Expect(err).ToNot(HaveOccurred())
 			} else {
 				Expect(err).To(HaveOccurred())
 			}
-			Expect(resized).To(Equal(wantResized))
 		})
 	},
-		table.Entry("successfully resize to imageSize when imageSize > info.VirtualSize and < totalSize", NewFakeQEMUOperations(nil, nil, fakeInfoRet, nil, nil, resource.NewScaledQuantity(int64(1500), 0)), "1500", int64(2048), false, true),
-		table.Entry("successfully resize to totalSize when imageSize > info.VirtualSize and > totalSize", NewFakeQEMUOperations(nil, nil, fakeInfoRet, nil, nil, resource.NewScaledQuantity(int64(2048), 0)), "2500", int64(2048), false, true),
-		table.Entry("successfully do nothing when imageSize = info.VirtualSize and > totalSize", NewFakeQEMUOperations(nil, nil, fakeInfoRet, nil, nil, resource.NewScaledQuantity(int64(1024), 0)), "1024", int64(1024), false, false),
-		table.Entry("fail to resize to with blank imageSize", NewFakeQEMUOperations(nil, nil, fakeInfoRet, nil, nil, resource.NewScaledQuantity(int64(2048), 0)), "", int64(2048), true, false),
-		table.Entry("fail to resize to with blank imageSize", NewQEMUAllErrors(), "", int64(2048), true, false),
+		table.Entry("successfully resize to imageSize when imageSize > info.VirtualSize and < totalSize", NewFakeQEMUOperations(nil, nil, fakeInfoRet, nil, nil, resource.NewScaledQuantity(int64(1500), 0)), "1500", int64(2048), false),
+		table.Entry("successfully resize to totalSize when imageSize > info.VirtualSize and > totalSize", NewFakeQEMUOperations(nil, nil, fakeInfoRet, nil, nil, resource.NewScaledQuantity(int64(2048), 0)), "2500", int64(2048), false),
+		table.Entry("successfully do nothing when imageSize = info.VirtualSize and > totalSize", NewFakeQEMUOperations(nil, nil, fakeInfoRet, nil, nil, resource.NewScaledQuantity(int64(1024), 0)), "1024", int64(1024), false),
+		table.Entry("fail to resize to with blank imageSize", NewFakeQEMUOperations(nil, nil, fakeInfoRet, nil, nil, resource.NewScaledQuantity(int64(2048), 0)), "", int64(2048), true),
+		table.Entry("fail to resize to with blank imageSize", NewQEMUAllErrors(), "", int64(2048), true),
 	)
 })
 
@@ -457,7 +462,7 @@ func (o *fakeQEMUOperations) Validate(*url.URL, int64, float64) error {
 	return o.e5
 }
 
-func (o *fakeQEMUOperations) Resize(dest string, size resource.Quantity) error {
+func (o *fakeQEMUOperations) Resize(dest string, size resource.Quantity, preallocate bool) error {
 	if o.resizeQuantity != nil {
 		Expect(o.resizeQuantity.Cmp(size)).To(Equal(0))
 	}
